/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#ifdef __M_THREAD_2_H__
#ifndef ___M_THREAD_2_END_H___
#define ___M_THREAD_2_END_H___

#define SCHED_SUPER_POLICY	SCHED_OTHER
#define SCHED_POLICY		SCHED_OTHER


typedef struct sw_hash {
	struct sw_hash *	next;
	unsigned int		key;
	int			cnt;
	sem_t  *		sem;
} SW_HASH;

typedef union thread_block {
	union thread_block * next;
	RW_LOCK		rw_lock;
	_SEM		sem;
	SW_HASH		sw_hash;
} THREAD_BLOCK;


#endif
#endif
